# -*- coding: utf-8 -*-
#
__version__ = '2.4.0'
__author__ = 'Nico Schlömer'
__author_email__ = 'nico.schloemer@gmail.com'
__website__ = 'https://github.com/nschloe/pygmsh'

from pygmsh.geometry import Geometry
from pygmsh.helper import *

__all__ = [
        'geometry',
        'helper'
        ]
